Changelog
=========

0.1 (2014-10-15)
----------------

- Initial draft

0.2 (2014-10-15 after sleeping)
-------------------------------

- Fixed packaging
- Fixed the ``revert`` behaviour
- Allow to revert without argument
- Improved doc

